==> liquidwar6-0.0.7beta.tar.gz: liquidwar6-0.0.7beta/src/scriptpo.c <==
_("no gfx backend found");	// extracted by scriptpo-update.sh
_("no snd backend found");	// extracted by scriptpo-update.sh
_("gfx backend ~a not available");	// extracted by scriptpo-update.sh
_("snd backend ~a not available");	// extracted by scriptpo-update.sh
_("red");			// extracted by scriptpo-update.sh
_("green");			// extracted by scriptpo-update.sh
_("blue");			// extracted by scriptpo-update.sh
_("yellow");			// extracted by scriptpo-update.sh
_("cyan");			// extracted by scriptpo-update.sh
_("magenta");			// extracted by scriptpo-update.sh
_("orange");			// extracted by scriptpo-update.sh
_("light blue");		// extracted by scriptpo-update.sh
_("purple");			// extracted by scriptpo-update.sh
_("pink");			// extracted by scriptpo-update.sh
_("Mouse");			// extracted by scriptpo-update.sh
_("Keyboard");			// extracted by scriptpo-update.sh
_("Joystick 1");		// extracted by scriptpo-update.sh
_("Joystick 2");		// extracted by scriptpo-update.sh
_("Custom");			// extracted by scriptpo-update.sh
_("~a (mouse)");		// extracted by scriptpo-update.sh
_("~a (keyb)");			// extracted by scriptpo-update.sh
_("~a (joy1)");			// extracted by scriptpo-update.sh
_("~a (joy2)");			// extracted by scriptpo-update.sh
_("~a (custom)");		// extracted by scriptpo-update.sh
_("~a (mouse)");		// extracted by scriptpo-update.sh
_("scheme error");		// extracted by scriptpo-update.sh
_("running scheme code with Guile");	// extracted by scriptpo-update.sh
_("leaving Guile");		// extracted by scriptpo-update.sh
_("catched Guile error");	// extracted by scriptpo-update.sh
_("begin main game loop");	// extracted by scriptpo-update.sh
_("running \"~a\"");		// extracted by scriptpo-update.sh
_("no graphical backend found, game can only run in pure server/console mode");	// extracted by scriptpo-update.sh
_("server mode not implemented yet");	// extracted by scriptpo-update.sh
_("Esc");			// extracted by scriptpo-update.sh
_("Quit");			// extracted by scriptpo-update.sh
_("Resume");			// extracted by scriptpo-update.sh
_("Quit Liquid War 6?");	// extracted by scriptpo-update.sh
_("Playing");			// extracted by scriptpo-update.sh
_("Choose map");		// extracted by scriptpo-update.sh
_("No sound FX");		// extracted by scriptpo-update.sh
_("Sound FX ~a%");		// extracted by scriptpo-update.sh
_("No music");			// extracted by scriptpo-update.sh
_("Music ~a%");			// extracted by scriptpo-update.sh
_("Backend ~a");		// extracted by scriptpo-update.sh
_("Sound options");		// extracted by scriptpo-update.sh
_("Armies ~a% - ~a%");		// extracted by scriptpo-update.sh
_("Fighter scale ~a");		// extracted by scriptpo-update.sh
_("Do not resample");		// extracted by scriptpo-update.sh
_("Keep map ratio");		// extracted by scriptpo-update.sh
_("Fit map to screen");		// extracted by scriptpo-update.sh
_("Use texture");		// extracted by scriptpo-update.sh
_("Ignore texture");		// extracted by scriptpo-update.sh
_("Use XML files");		// extracted by scriptpo-update.sh
_("Ignore XML files");		// extracted by scriptpo-update.sh
_("Use ~a");			// extracted by scriptpo-update.sh
_(" and ");			// extracted by scriptpo-update.sh
_("Map options");		// extracted by scriptpo-update.sh
_("One life (last wins)");	// extracted by scriptpo-update.sh
_("Respawn (deatchmatch)");	// extracted by scriptpo-update.sh
_("Cursors can have any color");	// extracted by scriptpo-update.sh
_("Can collaborate locally");	// extracted by scriptpo-update.sh
_("One cursor per team");	// extracted by scriptpo-update.sh
_("Rules");			// extracted by scriptpo-update.sh
_("Display FPS");		// extracted by scriptpo-update.sh
_("FPS hidden");		// extracted by scriptpo-update.sh
_("Display RPS");		// extracted by scriptpo-update.sh
_("RPS hidden");		// extracted by scriptpo-update.sh
_("Console enabled");		// extracted by scriptpo-update.sh
_("Console disabled");		// extracted by scriptpo-update.sh
_("System options");		// extracted by scriptpo-update.sh
_("Time ~a:~a~a:~a~a");		// extracted by scriptpo-update.sh
_("Speed ~ax~a=~a");		// extracted by scriptpo-update.sh
_("Time & speed");		// extracted by scriptpo-update.sh
_("Fullscreen");		// extracted by scriptpo-update.sh
_("Windowed");			// extracted by scriptpo-update.sh
_("Low res");			// extracted by scriptpo-update.sh
_("Standard res");		// extracted by scriptpo-update.sh
_("High res");			// extracted by scriptpo-update.sh
_("User res");			// extracted by scriptpo-update.sh
_("Backend ~a");		// extracted by scriptpo-update.sh
_("Video options");		// extracted by scriptpo-update.sh
_("Map");			// extracted by scriptpo-update.sh
_("Time & speed");		// extracted by scriptpo-update.sh
_("Rules");			// extracted by scriptpo-update.sh
_("Video");			// extracted by scriptpo-update.sh
_("Sound");			// extracted by scriptpo-update.sh
_("System");			// extracted by scriptpo-update.sh
_("Stop current game");		// extracted by scriptpo-update.sh
_("Options");			// extracted by scriptpo-update.sh
_("Options");			// extracted by scriptpo-update.sh
_("Local game");		// extracted by scriptpo-update.sh
_("Join network game");		// extracted by scriptpo-update.sh
_("Start server");		// extracted by scriptpo-update.sh
_("Demo");			// extracted by scriptpo-update.sh
_("Back to main menu");		// extracted by scriptpo-update.sh
_("Play");			// extracted by scriptpo-update.sh
_("Play");			// extracted by scriptpo-update.sh
_("Unknown bot");		// extracted by scriptpo-update.sh
_("Not playing");		// extracted by scriptpo-update.sh
_("Free slot");			// extracted by scriptpo-update.sh
_("Players");			// extracted by scriptpo-update.sh
_("Quick start");		// extracted by scriptpo-update.sh
_("Play");			// extracted by scriptpo-update.sh
_("Choose map");		// extracted by scriptpo-update.sh
_("Players");			// extracted by scriptpo-update.sh
_("Options");			// extracted by scriptpo-update.sh
_("Welcome to Liquid War 6");	// extracted by scriptpo-update.sh
_("Please wait...");		// extracted by scriptpo-update.sh
_("Please wait...");		// extracted by scriptpo-update.sh
_("Exit?");			// extracted by scriptpo-update.sh
_("Exit");			// extracted by scriptpo-update.sh
_("Resume LW6");		// extracted by scriptpo-update.sh
_("Liquid War 6");		// extracted by scriptpo-update.sh
_("Quick start");		// extracted by scriptpo-update.sh
_("Local game");		// extracted by scriptpo-update.sh
_("Network game");		// extracted by scriptpo-update.sh
_("Level");			// extracted by scriptpo-update.sh
_("Teams");			// extracted by scriptpo-update.sh
_("Options");			// extracted by scriptpo-update.sh
_("About");			// extracted by scriptpo-update.sh
_("Quick start");		// extracted by scriptpo-update.sh
_("About");			// extracted by scriptpo-update.sh
_("Authors");			// extracted by scriptpo-update.sh
_("Copyright");			// extracted by scriptpo-update.sh
_("License");			// extracted by scriptpo-update.sh
_("Version");			// extracted by scriptpo-update.sh
_("View level");		// extracted by scriptpo-update.sh
_("Confirm level choice");	// extracted by scriptpo-update.sh
_("Choose it");			// extracted by scriptpo-update.sh
_("View");			// extracted by scriptpo-update.sh
_("Cancel");			// extracted by scriptpo-update.sh
_("Level");			// extracted by scriptpo-update.sh
_("Options");			// extracted by scriptpo-update.sh
_("Graphics");			// extracted by scriptpo-update.sh
_("Sound");			// extracted by scriptpo-update.sh
_("Graphics options");		// extracted by scriptpo-update.sh
_("Fullscreen");		// extracted by scriptpo-update.sh
_("Graphics backend");		// extracted by scriptpo-update.sh
_("Sound options");		// extracted by scriptpo-update.sh
_("Sound fx volume");		// extracted by scriptpo-update.sh
_("Music volume");		// extracted by scriptpo-update.sh
_("Sound backend");		// extracted by scriptpo-update.sh
_("Graphics backend");		// extracted by scriptpo-update.sh
_("Sound backend");		// extracted by scriptpo-update.sh
_("testing map");		// extracted by scriptpo-update.sh
_("testing game struct");	// extracted by scriptpo-update.sh
_("testing game state");	// extracted by scriptpo-update.sh
_("testing pilot");		// extracted by scriptpo-update.sh
_("testing bot");		// extracted by scriptpo-update.sh
_("testing smobs GC, step 1");	// extracted by scriptpo-update.sh
_("testing smobs GC, step 2");	// extracted by scriptpo-update.sh
_("testing async load");	// extracted by scriptpo-update.sh

==> liquidwar6-0.0.8beta.tar.gz: liquidwar6-0.0.8beta/src/scriptpo.c <==
_("scheme error");		// extracted by scriptpo-update.sh
_("running scheme code with Guile");	// extracted by scriptpo-update.sh
_("leaving Guile");		// extracted by scriptpo-update.sh
_("catched Guile error");	// extracted by scriptpo-update.sh
_("Choose map");		// extracted by scriptpo-update.sh
_("Time ~a:~a~a:~a~a");		// extracted by scriptpo-update.sh
_("Default speed");		// extracted by scriptpo-update.sh
_("Speed x~a");			// extracted by scriptpo-update.sh
_("Speed ~a%");			// extracted by scriptpo-update.sh
_("Unknown speed");		// extracted by scriptpo-update.sh
_("Bench ~a");			// extracted by scriptpo-update.sh
_("Time & speed");		// extracted by scriptpo-update.sh
_("No sound FX");		// extracted by scriptpo-update.sh
_("Sound FX ~a%");		// extracted by scriptpo-update.sh
_("No music");			// extracted by scriptpo-update.sh
_("Music ~a%");			// extracted by scriptpo-update.sh
_("Backend ~a");		// extracted by scriptpo-update.sh
_("Sound options");		// extracted by scriptpo-update.sh
_("Fullscreen");		// extracted by scriptpo-update.sh
_("Windowed");			// extracted by scriptpo-update.sh
_("Low res");			// extracted by scriptpo-update.sh
_("Standard res");		// extracted by scriptpo-update.sh
_("High res");			// extracted by scriptpo-update.sh
_("User res");			// extracted by scriptpo-update.sh
_("Backend ~a");		// extracted by scriptpo-update.sh
_("Video options");		// extracted by scriptpo-update.sh
_("no gfx backend found");	// extracted by scriptpo-update.sh
_("no snd backend found");	// extracted by scriptpo-update.sh
_("gfx backend ~a not available");	// extracted by scriptpo-update.sh
_("snd backend ~a not available");	// extracted by scriptpo-update.sh
_("Quick start");		// extracted by scriptpo-update.sh
_("Play");			// extracted by scriptpo-update.sh
_("Choose map");		// extracted by scriptpo-update.sh
_("Players");			// extracted by scriptpo-update.sh
_("Options");			// extracted by scriptpo-update.sh
_("Welcome to Liquid War 6");	// extracted by scriptpo-update.sh
_("Quit");			// extracted by scriptpo-update.sh
_("Resume");			// extracted by scriptpo-update.sh
_("Quit Liquid War 6?");	// extracted by scriptpo-update.sh
_("Exit?");			// extracted by scriptpo-update.sh
_("Exit");			// extracted by scriptpo-update.sh
_("Resume LW6");		// extracted by scriptpo-update.sh
_("Liquid War 6");		// extracted by scriptpo-update.sh
_("Quick start");		// extracted by scriptpo-update.sh
_("Local game");		// extracted by scriptpo-update.sh
_("Network game");		// extracted by scriptpo-update.sh
_("Level");			// extracted by scriptpo-update.sh
_("Teams");			// extracted by scriptpo-update.sh
_("Options");			// extracted by scriptpo-update.sh
_("About");			// extracted by scriptpo-update.sh
_("Quick start");		// extracted by scriptpo-update.sh
_("About");			// extracted by scriptpo-update.sh
_("Authors");			// extracted by scriptpo-update.sh
_("Copyright");			// extracted by scriptpo-update.sh
_("License");			// extracted by scriptpo-update.sh
_("Version");			// extracted by scriptpo-update.sh
_("View level");		// extracted by scriptpo-update.sh
_("Confirm level choice");	// extracted by scriptpo-update.sh
_("Choose it");			// extracted by scriptpo-update.sh
_("View");			// extracted by scriptpo-update.sh
_("Cancel");			// extracted by scriptpo-update.sh
_("Level");			// extracted by scriptpo-update.sh
_("Options");			// extracted by scriptpo-update.sh
_("Graphics");			// extracted by scriptpo-update.sh
_("Sound");			// extracted by scriptpo-update.sh
_("Graphics options");		// extracted by scriptpo-update.sh
_("Fullscreen");		// extracted by scriptpo-update.sh
_("Graphics backend");		// extracted by scriptpo-update.sh
_("Sound options");		// extracted by scriptpo-update.sh
_("Sound fx volume");		// extracted by scriptpo-update.sh
_("Music volume");		// extracted by scriptpo-update.sh
_("Sound backend");		// extracted by scriptpo-update.sh
_("Graphics backend");		// extracted by scriptpo-update.sh
_("Sound backend");		// extracted by scriptpo-update.sh
_("testing map");		// extracted by scriptpo-update.sh
_("testing game struct");	// extracted by scriptpo-update.sh
_("testing game state");	// extracted by scriptpo-update.sh
_("testing pilot");		// extracted by scriptpo-update.sh
_("testing bot");		// extracted by scriptpo-update.sh
_("testing smobs GC, step 1");	// extracted by scriptpo-update.sh
_("testing smobs GC, step 2");	// extracted by scriptpo-update.sh
_("testing async load");	// extracted by scriptpo-update.sh
_("testing node");		// extracted by scriptpo-update.sh
_("begin main game loop");	// extracted by scriptpo-update.sh
_("Please wait...");		// extracted by scriptpo-update.sh
_("Please wait...");		// extracted by scriptpo-update.sh
_("Unknown bot");		// extracted by scriptpo-update.sh
_("Not playing");		// extracted by scriptpo-update.sh
_("Mouse");			// extracted by scriptpo-update.sh
_("Keyboard");			// extracted by scriptpo-update.sh
_("Joystick 1");		// extracted by scriptpo-update.sh
_("Joystick 2");		// extracted by scriptpo-update.sh
_("Custom");			// extracted by scriptpo-update.sh
_("~a (mouse)");		// extracted by scriptpo-update.sh
_("~a (keyb)");			// extracted by scriptpo-update.sh
_("~a (joy1)");			// extracted by scriptpo-update.sh
_("~a (joy2)");			// extracted by scriptpo-update.sh
_("~a (custom)");		// extracted by scriptpo-update.sh
_("~a (mouse)");		// extracted by scriptpo-update.sh
_("Time & speed");		// extracted by scriptpo-update.sh
_("Rules");			// extracted by scriptpo-update.sh
_("Map");			// extracted by scriptpo-update.sh
_("Video");			// extracted by scriptpo-update.sh
_("Sound");			// extracted by scriptpo-update.sh
_("System");			// extracted by scriptpo-update.sh
_("Stop current game");		// extracted by scriptpo-update.sh
_("Options");			// extracted by scriptpo-update.sh
_("Options");			// extracted by scriptpo-update.sh
_("Armies ~a% - ~a%");		// extracted by scriptpo-update.sh
_("Keep map ratio");		// extracted by scriptpo-update.sh
_("Fit map to screen");		// extracted by scriptpo-update.sh
_("Use texture");		// extracted by scriptpo-update.sh
_("Ignore texture");		// extracted by scriptpo-update.sh
_("Use XML files");		// extracted by scriptpo-update.sh
_("Ignore XML files");		// extracted by scriptpo-update.sh
_("Use ~a");			// extracted by scriptpo-update.sh
_(" and ");			// extracted by scriptpo-update.sh
_("Map options");		// extracted by scriptpo-update.sh
_("One life (last wins)");	// extracted by scriptpo-update.sh
_("Respawn (deatchmatch)");	// extracted by scriptpo-update.sh
_("Cursors can have any color");	// extracted by scriptpo-update.sh
_("Can collaborate locally");	// extracted by scriptpo-update.sh
_("One cursor per team");	// extracted by scriptpo-update.sh
_("Rules");			// extracted by scriptpo-update.sh
_("Local game");		// extracted by scriptpo-update.sh
_("Join network game");		// extracted by scriptpo-update.sh
_("Start server");		// extracted by scriptpo-update.sh
_("Demo");			// extracted by scriptpo-update.sh
_("Back to main menu");		// extracted by scriptpo-update.sh
_("Play");			// extracted by scriptpo-update.sh
_("Play");			// extracted by scriptpo-update.sh
_("running \"~a\"");		// extracted by scriptpo-update.sh
_("upgrading to version ~a");	// extracted by scriptpo-update.sh
_("no graphical backend found, game can only run in pure server/console mode");	// extracted by scriptpo-update.sh
_("server mode not implemented yet");	// extracted by scriptpo-update.sh
_("Display FPS");		// extracted by scriptpo-update.sh
_("FPS hidden");		// extracted by scriptpo-update.sh
_("Display MPS");		// extracted by scriptpo-update.sh
_("MPS hidden");		// extracted by scriptpo-update.sh
_("Console enabled");		// extracted by scriptpo-update.sh
_("Console disabled");		// extracted by scriptpo-update.sh
_("System options");		// extracted by scriptpo-update.sh
_("Playing");			// extracted by scriptpo-update.sh
_("red");			// extracted by scriptpo-update.sh
_("green");			// extracted by scriptpo-update.sh
_("blue");			// extracted by scriptpo-update.sh
_("yellow");			// extracted by scriptpo-update.sh
_("cyan");			// extracted by scriptpo-update.sh
_("magenta");			// extracted by scriptpo-update.sh
_("orange");			// extracted by scriptpo-update.sh
_("light blue");		// extracted by scriptpo-update.sh
_("purple");			// extracted by scriptpo-update.sh
_("pink");			// extracted by scriptpo-update.sh
_("Esc");			// extracted by scriptpo-update.sh
_("Free slot");			// extracted by scriptpo-update.sh
_("Players");			// extracted by scriptpo-update.sh
